@@ -4,7 +4,7 @@ from datetime import timedelta
 import numpy as np
 import pymzn
 
-from opoly.modules.minizinc import LAMPORT_ALLOCATOR
+from opoly.modules.minizinc import LAMPORT_ALLOCATOR_PATH
 from opoly.modules.minizinc.utils import solve_model
 
 
@@ -14,12 +14,12 @@ class LamportCPAllocator(ABC):
         if len(schedule.shape) != 1:
             return None, "Schedule must be a one-dimensional vector!"
         sol, err = solve_model(
-            model=LAMPORT_ALLOCATOR,
+            model=LAMPORT_ALLOCATOR_PATH,
             data={
-                "dim": schedule.shape[0],
-                "a": schedule.tolist()
+                "n": schedule.shape[0],
+                "tau": schedule.tolist()
             }
         )
         if sol is None:
             return None, err
-        return np.array(sol["A"]), None
+        return np.array(sol["T"]), None
