@@ -4,7 +4,7 @@ from datetime import timedelta
 import numpy as np
 import pymzn
 
-from opoly.modules.minizinc import LAMPORT_SCHEDULER
+from opoly.modules.minizinc import LAMPORT_SCHEDULER_PATH
 from opoly.modules.minizinc.utils import solve_model
 
 
@@ -16,13 +16,13 @@ class LamportCPScheduler(ABC):
         if not issubclass(deps.dtype.type, np.integer):
             return None, "Dependencies must be integers!"
         sol, err = solve_model(
-            model=LAMPORT_SCHEDULER,
+            model=LAMPORT_SCHEDULER_PATH,
             data={
-                "k": deps.shape[0],
+                "r": deps.shape[0],
                 "n": deps.shape[1],
-                "deps": deps.tolist()
+                "D": deps.tolist()
             }
         )
         if sol is None:
             return None, err
-        return np.array(sol["a"]), None
+        return np.array(sol["tau"]), None
